11c1c560b88d430fd2c6967a86d2e87109806357
max
  Fri Jan 24 09:15:03 2014 -0800
corrections after code review refs #12524. These changes probably don'tneed to reviewed anymore, as Angie has already seen them, I copied them into
the ticket #12524.

diff --git src/inc/udc.h src/inc/udc.h
index c081b75..b7db8f6 100644
--- src/inc/udc.h
+++ src/inc/udc.h
@@ -141,24 +141,25 @@
 int udcCacheTimeout();
 /* Get cache timeout (if local cache files are newer than this many seconds,
  * we won't ping the remote server to check the file size and update time). */
 
 void udcSetCacheTimeout(int timeout);
 /* Set cache timeout (if local cache files are newer than this many seconds,
  * we won't ping the remote server to check the file size and update time). */
 
 time_t udcUpdateTime(struct udcFile *udc);
 /* return udc->updateTime */
 
 boolean udcFastReadString(struct udcFile *f, char buf[256]);
 /* Read a string into buffer, which must be long enough
  * to hold it.  String is in 'writeString' format. */
 
-#ifdef PROGRESS_METER
-off_t remoteFileSize(char *url);
-/* fetch remote file size from given URL */
-#endif /* PROGRESS_METER */
+off_t udcFileSize(char *url);
+/* fetch remote or loca file size from given URL or path */
+
+boolean udcExists(char *url);
+/* return true if a remote or local file exists */
 
 boolean udcIsLocal(char *url);
 /* return true if url is not a http or ftp file, just a normal local file path */
 
 #endif /* UDC_H */